package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@(!`0D```````````(`/@`!````8!]```````!``````````("\````
M`````````$``.``(`$``&@`9``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````$2U````````1+4`````````
M`"````````$````&````2+4```````!(M6```````$BU8```````*`0`````
M``"`"0``````````(````````@````8```!PM0```````'"U8```````<+5@
M``````#@`0```````.`!````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````#+$````````,L4````````RQ0```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`,R[#0!A````9@`````````<`````````#D`````
M````+````&,````C``````````````!.`````````%0```!,`````````#0`
M```[````80````(````N````5P```!`````V````````````````````'@``
M`%`````E````5@`````````K````7P```$T````+````3P```&````!B````
M*````&4`````````/`````````!3`````````%4```!>```````````````&
M````'0```!(````D````,`````H```!%````/@```$(```!<`````````$,`
M```]`````````%(`````````````````````````6````"D````7````2@``
M`"T```!``````````````````````P```!L````%````9````%T```!!````
M`````"`````)````````````````````/P````````!9````#P````````!$
M````1@```````````````````````````````0``````````````````````
M````````````````````````````````````````#0``````````````````
M````````````````````````````````````````````````````````````
M&@```````````````````!D````(````$0```````````````````!0````,
M````#@`````````5`````````````````````````"8````8````````````
M```````````````````````````````````A````$P``````````````````
M`#$````````````````````X````*@`````````?````%@```"<```!)````
M`````#,``````````````$L````B````40```"\`````````````````````
M```````````````U````-P````0```!'````2````%H``````````````#(`
M```Z````6P````<`````````````````````````````````````````=@$`
M`!(``````````````"$!````````F0,``!(`#`#@3D````````4`````````
MJ@,``!(`#`!P($```````#0`````````#````!(``````````````!4`````
M````#P0``!(``````````````!X`````````9P,``!(`#`!@'T```````)P`
M````````%@```!(``````````````$,%````````;`(``!(`````````````
M````````````(0```!$`%P"`N6````````$`````````30(``!(`````````
M````````````````.````"``````````````````````````80(``!$`%@!`
MN6````````@`````````3````!(`#0!$4D``````````````````MP,``!(`
M#`#P3D```````,@"````````S0,``!(`#`#P-T```````$T`````````VP,`
M`!(`#``03D```````,D`````````4@```!(```````````````0$````````
M6P```!$`%P"(N6````````$`````````9@```!(``````````````)$#````
M````=````!(``````````````$(`````````\0,``!(`#`#@/T```````.(`
M````````_0,``!(`#`"P/T```````"(`````````A````!$`%P"0N6``````
M``$`````````D@```!(``````````````&$!````````HP(``!(`````````
M`````"\`````````Y`(``!(```````````````P`````````&`0``!(`#`#0
M0$```````&T`````````+0(``!$`%P"4N6````````0`````````5`,``!(`
M``````````````\`````````"@,``!(`````````````````````````10,`
M`!(``````````````&P`````````H````!$`%P"@N6````````@`````````
M,@,``!(`````````````````````````J@```!(``````````````"L`````
M````&`,``!(```````````````(`````````M0```!(```````````````H#
M````````30,``!(``````````````%4`````````,00``!$`#@`@54``````
M`.I;````````PP```!$`%P"HN6````````@`````````*0,``!(`````````
M`````)``````````]`(``!(`````````````````````````R0```!(`````
M`````````!8`````````F`(``!(``````````````&<`````````UP```!$`
M%P"PN6````````@`````````B0(``!(``````````````/0`````````Y```
M`!(````T'4```````",$````````G@(``!(`````````````````````````
M]````!$`%P"XN6````````$`````````_P```!(```````````````\!````
M````$`$``!(``````````````$P'````````,0,``!(`````````````````
M````````'P$``!$`%P#`N6````````@`````````(@,``!(`````````````
M````````````>P(``!(`````````````````````````=0(``!(`````````
M````````````````)`0``!(`#`#`44```````!0`````````@0(``!(`````
M`````````#0`````````+P$``!(``````````````'$"````````/0$``!(`
M`````````````%D<````````J@(``!(`````````````````````````^@(`
M`!(``````````````$P`````````TP(``!(```````````````P`````````
M8@,``!``\?]PN6``````````````````2P$``!$`%P#`OF````````@`````
M````4P$``!(``````````````+H`````````60(``!(``````````````(\0
M`````````@,``!(```````````````@`````````D`(``!(`````````````
M``H`````````+`0``!$`%@!@N6````````@`````````4@(``!(`````````
M`````$H`````````7P$``!$`%P#(N6````````@`````````0`0``!(`#`!`
M.$```````!X`````````.P(``!$`%P#@N6```````$``````````-P,``!(`
M`````````````'P`````````;@,``!``\?_(OF``````````````````L0(`
M`!(`````````````````````````$0,``!(``````````````%0`````````
M:@$``!(``````````````#8`````````7`0``!$`%@!HN6````````@`````
M````P`(``!$`%P`@NF````````@`````````?0$``!(``````````````)``
M````````B@$``!$`%P!`NF````````$`````````EP$``!$`%P!0NF``````
M`!,`````````I0(``!(``````````````"\`````````<`0``!(`#`#@1$``
M`````"@)````````I@$``!(``````````````(T`````````6P,``!``\?]P
MN6``````````````````$0```!(``````````````"P'````````L0$``!(`
M`````````````)@"````````?00``!(`#`#@/$````````T!````````CP0`
M`!(`#``P0T```````*P!````````O`$``!(``````````````&<`````````
MN`(``!(``````````````$H`````````ZP(``!(``````````````)L`````
M````/@,``!(``````````````'X`````````G`0``!(`#`#P/4```````+X!
M````````J00``!(`#`!`04```````/`!````````)@0``!(`"@"`&T``````
M````````````RP$``!$`%P!HNF````````@`````````U0$``!(`````````
M`````'L`````````[`$``!(``````````````-L'`````````&QI8G!E<FPN
M<V\`<&5R;%]F<F5E`'!E<FQ?<&%R<V4`4$Q?<&5R;%]D97-T<G5C=%]L979E
M;`!?2G9?4F5G:7-T97)#;&%S<V5S`%]F:6YI`'!E<FQ?<G5N`%!,7VEN7V5V
M86P`4&5R;%]A=E]S:&EF=`!097)L7V=V7V9E=&-H<'8`4$Q?97AI=%]F;&%G
M<P!097)L7W-V7W-E='!V`%!,7V-O;7!C=@!P97)L7V%L;&]C`%!E<FQ?9&]U
M;G=I;F0`4$Q?;W``4&5R;%]S>7-?=&5R;0!03%]E=F%L7W)O;W0`8F]O=%]$
M>6YA3&]A9&5R`%!,7W1A:6YT960`4&5R;%]N97=84U]F;&%G<P!P97)L7V-O
M;G-T<G5C=`!03%]C=7)S=&%C:VEN9F\`4&5R;%]A=E]F971C:`!P97)L7V1E
M<W1R=6-T`&5N=FER;VX`4&5R;%]M9U]S970`4$Q?=&]P7V5N=@!097)L7W-A
M9F5S>7-M86QL;V,`4&5R;%]N97=35G!V`%!,7V1O7W5N9'5M<`!03%]M96UO
M<GE?=W)A<`!097)L7V-R;V%K`%!E<FQ?;F5W6%,`4&5R;%]S>7-?:6YI=#,`
M4$Q?<&%R<V5R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]S=E\R<'9?
M9FQA9W,`;&EB;2YS;RXU`&QI8F-R>7!T+G-O+C4`;&EB=71I;"YS;RXY`&QI
M8F,N<V\N-P!?7VUB7W-B7VQI;6ET`%]?<W1A8VM?8VAK7V=U87)D`&]P96X`
M;65M8W!Y`')E86QL;V,`7U]P<F]G;F%M90!R96%D;&EN:P!R;61I<@!M:V1I
M<@!S=')N8VUP`'-T<FQE;@!O<&5N9&ER`&QS965K`')E860`871E>&ET`&%C
M8V5S<P!G971P:60`;65M;6]V90!?0W5R<F5N=%)U;F5,;V-A;&4`7U]S=&%C
M:U]C:&M?9F%I;`!S=')T;VL`8VQO<V5D:7(`8VQO<V4`<W1R;F-P>0!?7V5R
M<F]R`'5N;&EN:P!M96US970`7VEN:71?=&QS`&=E='5I9`!S<')I;G1F`&QS
M=&%T`'-T<G-T<@!S=')C;7``<F5A9&1I<@!S=')D=7``97AE8W9P`%]E9&%T
M80!?7V)S<U]S=&%R=`!?96YD`"]U<W(O;&]C86PO;&EB+W!E<FPU+S4N,3(N
M-"]M86-H+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?
M26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?
M97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`'AS7VEN:70`;F%M95]L;V%D7VUY7W!A<E]P;`!8
M4U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<VEZ95]L;V%D7VUY7W!A<E]P
M;`!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G
M`'!A<E]I;FET7V5N=@!M86EN`$9"4T1?,2XP``````(``0`!`````@`!````
M`@````(````!``$``0`!``$````````````!``$```````(``@`!``(``@`"
M``(````"`````@````(``0````(``@````(````"`````@`````````"````
M`@`"``(``0`"```````"``(``@`!``$````"``(``@`!``(````!``(``@`!
M``(``@````$``@`````````"``$````!``(````!``$````"``(``@`!``$`
M`0```````````````0`!`","```0`````````+`H>@<```(`K@0```````"`
MN6````````4````)``````````````"(N6````````4````2````````````
M``"0N6````````4````7``````````````"4N6````````4````<````````
M``````"@N6````````4````@``````````````"HN6````````4````G````
M``````````"PN6````````4````L``````````````"XN6````````4````P
M``````````````#`N6````````4````T``````````````#(N6````````4`
M``!'``````````````#@N6````````4```!)```````````````@NF``````
M``4```!0``````````````!`NF````````4```!2``````````````!0NF``
M``````4```!3``````````````!HNF````````4```!C``````````````!H
MMV````````<````!``````````````!PMV````````<````$````````````
M``!XMV````````<````%``````````````"`MV````````<````'````````
M``````"(MV````````<````(``````````````"0MV````````<````*````
M``````````"8MV````````<````1``````````````"@MV````````<````3
M``````````````"HMV````````<````4``````````````"PMV````````<`
M```8``````````````"XMV````````<````9``````````````#`MV``````
M``<````:``````````````#(MV````````<````=``````````````#0MV``
M``````<````>``````````````#8MV````````<````?``````````````#@
MMV````````<````A``````````````#HMV````````<````B````````````
M``#PMV````````<````C``````````````#XMV````````<````D````````
M````````N&````````<````E```````````````(N&````````<````H````
M```````````0N&````````<````I```````````````8N&````````<````J
M```````````````@N&````````<````K```````````````HN&````````<`
M```M```````````````PN&````````<````N```````````````XN&``````
M``<````O``````````````!`N&````````<````Q``````````````!(N&``
M``````<````R``````````````!0N&````````<````S``````````````!8
MN&````````<````U``````````````!@N&````````<````V````````````
M``!HN&````````<````W``````````````!PN&````````<````Y````````
M``````!XN&````````<````Z``````````````"`N&````````<````[````
M``````````"(N&````````<````\``````````````"0N&````````<````]
M``````````````"8N&````````<````^``````````````"@N&````````<`
M``!!``````````````"HN&````````<```!"``````````````"PN&``````
M``<```!#``````````````"XN&````````<```!$``````````````#`N&``
M``````<```!&``````````````#(N&````````<```!*``````````````#0
MN&````````<```!,``````````````#8N&````````<```!-````````````
M``#@N&````````<```!.``````````````#HN&````````<```!1````````
M``````#PN&````````<```!4``````````````#XN&````````<```!6````
M````````````N6````````<```!8```````````````(N6````````<```!9
M```````````````0N6````````<```!<```````````````8N6````````<`
M``!=```````````````@N6````````<```!>```````````````HN6``````
M``<```!?```````````````PN6````````<```!D```````````````XN6``
M``````<```!E``````````````!(@^P(Z+<$``#H@C8``$B#Q`C#`/\UOIL@
M`/\EP)L@``\?0`#_);Z;(`!H`````.G@_____R6VFR``:`$```#IT/____\E
MKIL@`&@"````Z<#_____)::;(`!H`P```.FP_____R6>FR``:`0```#IH/__
M__\EEIL@`&@%````Z9#_____)8Z;(`!H!@```.F`_____R6&FR``:`<```#I
M</____\E?IL@`&@(````Z6#_____)7:;(`!H"0```.E0_____R5NFR``:`H`
M``#I0/____\E9IL@`&@+````Z3#_____)5Z;(`!H#````.D@_____R56FR``
M:`T```#I$/____\E3IL@`&@.````Z0#_____)4:;(`!H#P```.GP_O___R4^
MFR``:!````#IX/[___\E-IL@`&@1````Z=#^____)2Z;(`!H$@```.G`_O__
M_R4FFR``:!,```#IL/[___\E'IL@`&@4````Z:#^____)1:;(`!H%0```.F0
M_O___R4.FR``:!8```#I@/[___\E!IL@`&@7````Z7#^____)?Z:(`!H&```
M`.E@_O___R7VFB``:!D```#I4/[___\E[IH@`&@:````Z4#^____)>::(`!H
M&P```.DP_O___R7>FB``:!P```#I(/[___\EUIH@`&@=````Z1#^____)<Z:
M(`!H'@```.D`_O___R7&FB``:!\```#I\/W___\EOIH@`&@@````Z>#]____
M);::(`!H(0```.G0_?___R6NFB``:"(```#IP/W___\EIIH@`&@C````Z;#]
M____)9Z:(`!H)````.F@_?___R66FB``:"4```#ID/W___\ECIH@`&@F````
MZ8#]____)8::(`!H)P```.EP_?___R5^FB``:"@```#I8/W___\E=IH@`&@I
M````Z5#]____)6Z:(`!H*@```.E`_?___R5FFB``:"L```#I,/W___\E7IH@
M`&@L````Z2#]____)5::(`!H+0```.D0_?___R5.FB``:"X```#I`/W___\E
M1IH@`&@O````Z?#\____)3Z:(`!H,````.G@_/___R4VFB``:#$```#IT/S_
M__\E+IH@`&@R````Z<#\____)2::(`!H,P```.FP_/___R4>FB``:#0```#I
MH/S___\E%IH@`&@U````Z9#\____)0Z:(`!H-@```.F`_/___R4&FB``:#<`
M``#I</S___\E_ID@`&@X````Z6#\____)?:9(`!H.0```.E0_/___R7NF2``
M:#H```#I0/S__P```````````````%5(B>5!54R-;PA!5%-(@^P(BQ](8\.%
MVTR-9,<03(DE/)\@`'XZ2(M7"$B%TG0Q2(D5JID@``^V`H3`="-(@\(!/"](
MBP66F2``2`]$PDB)!8N9(``/M@)(@\(!A,!UX;APM6``2(7`="M(B??H<OS_
M_[]$4D``Z&C\___HG_O__XG?3(GB3(GNZ%(A``")Q^B__O__Z+K\___KUI"0
MD)"`/6F:(```54B)Y700ZR202(/`"$B)!369(`#_TDB+!2R9(`!(BQ!(A=)U
MY,8%/9H@``')PP\?1```9@\?1```54B#/1^5(```2(GE=!:X`````$B%P'0,
MOVBU8`!)B</)0?_CR<.0D)"0D)"0D)"0#[8/2(GXA,ET*$B+!>\S``!(C5<!
M#[8P2(GX#Q]$``!`./$/M@I(#T3"2(/"`83)=>[SPV8/'T0``&8/'T0``$%6
M2(UW.$%505152(G]4TB![`@"``!,C4PDB$V-@8````!,B<](BPY(@\8(2(G*
M2(G(2,'B"$C!X!@E````_X'B``#_`$@)PDB)R$C!Z`@E`/\``$@)PDB)R$C!
MZ!@E_P```$@)PDB)R$C!Z2A(P>@@2(D72,'@"$B)PDC!X!`E````_X'B``#_
M`$@)PDB)R$C!Z1`E`/\``$@)PD@)RDB)5PA(@\<03#G'#X5U____28U):$F-
ML6@"```/'T0``$B+`4@S0=A(,T&H2#-!F$B)PD@!P$C!ZA]("<*#XO](B5$8
M2(/!"$@Y\7743(MU`$B+?"2(0;W<O!N/2`-]($B+30A,BU402(MU&$R)\$R)
M\DV)\4C!X@5(P>@;28G(2`G03(G22<'H`H/@_T@ARDG!Z0)(C;P'F7F"6DB)
MR$C!X1Y(]]!)"<A((?!!@^#_2`-T))!("=!,B<(!QTR)\$PA\DCWT$B)^4PA
MT$C!Z1M,`U0DF$@)PDB)^$C!X`5(C;06F7F"6DB)^D@)P4R)\$C!X!X!\4D)
MP4B)^$B)SD&#X?](]]!(P>X;3"'*3"'`2`G02(G*38V4`IEY@EI(B<A(P>`%
M2`G&2(G(1`'628GZ2/?02<'J`DC!YQY,`T0DH$D)^DPAR$B)]T&#XO](P>\;
M3`-,)*A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>
M2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3`-4)+!,(<)("=!(B?I-C8P!F7F"
M6DB)^$C!X`5("<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4PAP$B)SD&#X?](
MP>X;3"'*2`G02(G*38V4`IEY@EI(B<A(P>`%3`-$)+A("<9(B<A$`=9)B?I(
MP><>2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;3`-,),!,(=)("=!(B?)-C80`
MF7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#
MX/](P>D;3`-4),A,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)
MB?%(P>8>2<'I`DCWT$D)\4PAP$B)SD&#X?],(<I(P>X;3`-$)-!("=!(B<I-
MC90"F7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)
M]T&#XO](P>\;3`-,)-A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$
M`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,
M`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F'DG!Z0)(]]!)"?%(B<Y!@^'_
M3`-4).!,(<!,(<I(P>X;3`-$).A("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(
MB<A$`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;3`-,)/!,(=)(
M"=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)
MR$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%2`G!2(GX
M1`')28GQ2/?02<'I`DC!YAY,`U0D^$D)\4PAP$B)SD&#X?](P>X;3`,$)$PA
MRD@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!YQY)P>H"2/?0
M28GS20GZ3"'(2(GW08/B_TC![QM,`TPD"$PATD@)T$B)\DV-A`"9>8):2(GP
M2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,
M(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5(P>8>2<'K`DP#5"002`G!20GS2(GX
M08/C_T0!R4CWT$PAVDB)SDPAP$F)^4C![AM("=!(P><>2<'I`DV-E`*9>8):
M2(G(3`-$)!A(P>`%20GY2(G*2`G&2(G(08/A_TCWT$PARD0!UDPAV$B)]TF)
MRD@)T$C!X1Y(P>\;38V$`)EY@EI(B?!)P>H"2,'@!4P#7"0@20G*2`G'2(GP
M08/B_TB)\DCWT$0!QTPAR$F)\$PATD@)T$C!YAY)P>@"38V<`YEY@EI)"?!(
MB?I(B?A!@^#_3`-,)"A(P>`%2,'J&T@)PDR)P$PQT$0!VDP#5"0P2#'X2(G1
M38V,`:'KV6Y(B=!(P>D;2,'@!4@)P40!R4F)^4C!YQY)P>D"2(G.20GY2(G7
M2,'N&T&#X?](P>\"3(G(3#'`3`-$)#A(,=!(P>(>38V4`J'KV6Y("==(B<B#
MY_](P>`%2`G&2(GX1`'63#'(3`-,)$!(,<A(B?)-C80`H>O9;DB)\$C!ZAM(
MP>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1(
M2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_
M2,'N&TR)R$PQP$P#1"102#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>
M2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`TPD6$@QR$V-A`"AZ]EN2(GP2,'@
M!4@)PD0!PDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD8$@Q
M\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC!
M[AM,B<A,,<!,`T0D:$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC!
M[P)("==(B?*#Y_](B?A,,<A(P>H;3`-,)'!(,<A-C80`H>O9;DB)\$C!X`5(
M"<)$`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)'A(,?!-
MC8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;
M3(G(3#'`3`.$)(````!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(
MP>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#C"2(````2#'(38V$`*'KV6Y(B?!(
MP>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#O"20
M````2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!
M@^'_2,'N&TR)R$PQP$P#A"28````2#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(
MB==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`XPDH````$@QR$V-A`"A
MZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"28G220G(2(G12<'J`D&#X/](
MP>D;3(G`2#'X2`.\)*@```!(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(
MP>8>2<'I`DF)S$D)\4B)SD&#X?](P>X;3(G(3#'`3`.$)+````!(,=!(P>(>
M2(V\!Z'KV6Y)"=)(B<A!@^+_2,'@!4@)QDR)T`'^3#'(2<'L`D@QR$C!X1Y(
MB?)-C80`H>O9;DD)S$B)\$&#Y/],`XPDN````$C!X`5(P>H;2(GS2(N,),@`
M``!("<),B>!(P>L"3#'01`'"3`.4),````!(,?!(P>8>2(G738V,`:'KV6Y(
M"?-(B="#X_](P>`%2,'O&T@)QTB)V$F)TTPQX$0!STG!ZP)(,=!(P>(>28GX
M38V4`J'KV6Y)"=-(B?A!@^/_2,'@!4G!Z!M)"<!,`>E,B=A%`=!,B=I,`>%(
M"=A((=I,B<9((?A)B?E(P>X;2`G02,'G'DG!Z0)(`<%,B<!)"?E(P>`%08/A
M_TV)PD@)QDR)R$R)R@'.2(N,)-````!,"=A,(=I,(<!(B?=("=!(P>\;2<'@
M'DP!Z4G!Z@)!O-;!8LI(`=E-"<)(`<%(B?!!@^+_2,'@!4R)TD@)QTR)T`'/
M2(N,)-@```!,"<A((?!)B?A,`>E,`=E,(<I)B?-("=!(P>8>2<'H&T@!P4B)
M^$G!ZP)(P>`%20GS20G`08/C_T$!R$B+C"3@````3(G83`G03(G:3(G&3"'2
M2"'X2,'N&TP!Z4@)T$P!R4F)^4C!YQY(`<%,B<!)P>D"2,'@!4D)^4@)QD&#
MX?\!SDB+C"3H````3(G(3`G83(G*2(GW3"':3"'`3`'I2`G03`'138G"2`'!
M2(GP2,'O&TC!X`5)P>`>2<'J`D@)QTT)P@'/08/B_TB+C"3P````3(G03(G2
M28GX3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!YAY(P>`%2<'K
M`DD)P$D)\T$!R$&#X_](BXPD^````$R)V$R)VDR)QDP)T$PATDC![AM,`>E(
M(?A("=!,`<E)B?E(`<%,B<!(P>`%2`G&`<Y(P><>2<'I`DD)^4B+C"0``0``
M2(GW08/A_TC![QM,B<A,B<I,"=A,(=I,`>E,(<!,`=%-B<)("=!)P>`>2<'J
M`D@!P4B)\$T)PDC!X`5!@^+_2`G'3(G03(G2`<](BXPD"`$``$P)R$PARD@A
M\$F)^$@)T$G!Z!M,`>E,`=E)B?-(P>8>2`'!2(GX2<'K`DC!X`5)"<!!`<A)
M"?-(BXPD$`$``$&#X_],B<9,B=A,B=I(P>X;3`G03"'23`'I2"'X3`')28GY
M2`G02,'G'DG!Z0)(`<%,B<!)"?E(P>`%08/A_T@)QDR)R$R)R@'.2(N,)!@!
M``!,"=A,(=I,(<!(B?=("=!(P>\;3`'I3`'138G"2<'@'D@!P4B)\$G!Z@)(
MP>`%30G"2`G'08/B_P'/2(N,)"`!``!,B=!,B=))B?A,`>E,`=E,"<A,(<I(
M(?!)B?-)P>@;2`G02,'F'DG!ZP)(`<%(B?A)"?-(P>`%08/C_TD)P$R)V$R)
MVD$!R$B+C"0H`0``3`G03"'22"'X3(G&2`G02,'N&TP!Z4P!R4F)^4C!YQY(
M`<%,B<!)P>D"2,'@!4D)^4@)QD&#X?\!SDB+C"0P`0``3(G(3`G83(G*2(GW
M3"'`3`'I3`'13"':38G"2`G02<'@'DC![QM(`<%(B?!)P>H"2,'@!4T)PD@)
MQT&#XO\!STB+C"0X`0``3(G03`G(3(G228GX3"'*2"'P2<'H&TP!Z4@)T$P!
MV4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)\TD)P$&#X_]!`<A(BXPD0`$``$R)
MV$P)T$R)VDR)QDPATD@A^$P!Z4@)T$P!R4F)^4@!P4R)P$C![AM(P>`%2,'G
M'DG!Z0)("<9)"?D!SD&#X?](BXPD2`$``$R)R$R)RDB)]TP)V$PAVDC![QM,
M`>E,(<!("=!,`=%-B<)(`<%(B?!)P>`>2,'@!4G!Z@)("<=-"<(!ST&#XO](
MBXPD4`$``$R)T$R)TDF)^$P)R$PARDG!Z!M,`>E((?!("=!,`=E)B?-(`<%(
MB?A(P>`%20G`00'(2,'F'DG!ZP))"?-(BXPD6`$``$R)QD&#X_](P>X;3(G8
M3(G:3`'I3`G03"'23`')2"'X28GY2`G02,'G'DG!Z0)(`<%)"?E,B<!!@^'_
M3`.L)&`!``!(P>`%2`G&3(G(3(G*3`G83"':`<Y,(<!(B?=("=!-`=5(P>\;
M20'%2(GP38G"2,'@!4G!X!Y)P>H"2`G'2(N4)&@!``!$`>]-"<))B?!!@^+_
M2(GY2<'H`DR)T$P!XDC!Z1M,,<A,`=I(,?!(P>8>2`'"2(GX20GP2,'@!4&#
MX/]("<%,B<`!T4B+E"1P`0``3#'02#'X2(G.2,'N&TP!XDP!RDF)^4C!YQY(
M`<)(B<A)P>D"2,'@!4D)^4@)QD&#X?\!UDB+E"1X`0``3(G(3#'`2(GW2#'(
M3`'B3`'228G*2`'"2(GP2,'O&TC!X`5(P>$>2<'J`D@)QTD)R@'72(N4)(`!
M``!!@^+_3(G02(GY3#'(2,'I&TP!XD@Q\$P!PDF)\$C!YAY(`<)(B?A)P>@"
M2,'@!4D)\$@)P4&#X/\!T4B+E"2(`0``3(G`3#'02(G.2#'X2,'N&TP!XDP!
MRDF)^4C!YQY(`<)(B<A)P>D"2,'@!4D)^4@)Q@'62(N4))`!``!!@^'_3(G(
M2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)
MQT&#XO\!UTB+E"28`0``3(G03#'(2(GY2#'P2,'I&TP!XDP!PDF)\$C!YAY(
M`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2@`0``3(G`3#'02(G.2#'X
M2,'N&TP!XDP!RDF)^4@!PDB)R$C!X`5(P><>2<'I`D@)QDD)^0'62(N4)*@!
M``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"
M2,'@!4D)RD@)QT&#XO\!UTB+E"2P`0``3(G03#'(2(GY2#'P2,'I&TP!XDP!
MPDF)\$C!YAY(`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2X`0``3(G`
M2(G.3`'B3#'02,'N&T@Q^$P!RDF)^4@!PDB)R$C!YQY(P>`%2<'I`D@)QDD)
M^0'62(N4),`!``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(
M`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"3(`0``3(G03#'(2(GY2#'P
M2,'I&TP!XDP!PDF)\$@!PDB)^$C!X`5("<%(P>8>2<'H`@'120GP2(N4)-`!
M``!!@^#_2(G.3(G`2,'N&TP!XDPQT$@Q^$P!RDF)^4@!PDB)R$C!YQY(P>`%
M2<'I`D@)QDD)^0'62(N4)-@!``!!@^'_3(G(2(GW28GS3#'`2,'O&TP!XD@Q
MR$P!TDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"3@`0``
M3(G02(GY2(G[3`'B3`'"3#'(2,'I&T@Q\$G!ZP)(P>8>2`'"2(GX20GS2,'@
M!4&#X_](P>L"2`G!3(G8`=%(BY0DZ`$``$PQT$@Q^$F)R$C!YQY)P>@;2`G[
M3`'B@^/_3`'*28G)2`'"2(G(2,'@!4D)P$B)V$$!T$B+E"3P`0``3#'82#'(
M3(G'3(G&2,'O&TP!XDP!TD@!PDR)P$C!X`5("<<!UTC!X1Y)P>D"20G)2(N4
M)/@!``!(P>X"08/A_TB)^4R)R$C!Z1M,`>)(,=A,`Z0D``(``$PQP$P!VDG!
MX!Y(`<),"<9(B?A(P>`%@^;_2`G!2(GP20'<3#'(`=%(,?A(B<I)`<1(B<A(
MP>(%2,'H&T@)T$0!X$0!\$B)10!(B?A(P><>2,'H`@--"$@)^`-%$`-U&$0#
M32!(B4T(2(E%$$B)=1A,B4T@2('$"`(``%M=05Q!74%>PTR)9"3@3(E\)/A)
MB?Q(B5PDT$B);"3828GW3(EL).A,B70D\$B#[#A(A?]U)3'`2(M<)`A(BVPD
M$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,-,BS7'AR``387V=,\/M@>$P'4$
M,<#K%SP]2(GZ=/5(@\(!#[8"A,!U18G01"G@28LN2(7M=*5,8^A,B?-FD$R)
MZDR)YDB)[^AVYO__A<!U"DF-1"T`@#@]=!I(BVL(2(/#"$B%[777Z6____]F
MD#P]=:SKM4PI\TB#P`%(P?L#08D?Z5;___\/'X``````55-(B?M(@^P82(UL
M)!1FD#'`2(GN2(G?Z`/___](A<!T)DAC1"042(T4Q0````!(`Q4*AR``2(/"
M"$B+`DB%P$B)0OAU\.O(2(/$&%M=PY!(@^P8,<!(C70D%.C`_O__2(/$&,,/
M'T0``&8/'T0``$B#[`B#/5V!(`#_=`N+!56!(`!(@\0(PS'`OV!20`#HO/__
M_TB%P'0'#[8`A,!U$S'`B04P@2``BP4J@2``2(/$",,\,`^5P`^VP.OE#Q\`
M2(/L"+______Z';D__\Q]K]@.$``2(/$".G6YO__9I!(BP59@2``4S'VO_]3
M0`!(BT@(2(L%+H$@``^W4"`/M@4#@2``9H'B_P&#X'_!X@<)PF:)40)(BP4C
M@2``2(M8".C^Y?__2(E#*$B+!0^!(`!(BU`(2(L%](`@`$B)0C!(BP7Y@"``
M,=)(BT@(2(L%E($@`$B%P'0'2(N0J````$B)43A(BP75@"``2(M`"$C'0$``
M````2(L%PH`@`$B+0`A(QT`@`````$B+!:^`(`!(BU`(2(L%K(`@`$B)0DA;
MPP\?@``````/'X``````3(ED).A(B5PDV$F)_$B);"3@3(EL)/!,B70D^$B!
M[*@```!(A?]T!8`_`'4S2(N<)(````!(BZPDB````$R+I"20````3(NL))@`
M``!,B[0DH````$B!Q*@```###Q\`Z*_D__](A<!(B<5TP`\?`$B)[^C<XO__
M2(7`#X2A````2(U8"+]K4D``N0(```#\2(G>\Z9TV;]J4D``N0,```!(B=[S
MIG3(3(GGZ$3C__](B=])B<7H.>/__T&-1`4"2&/XZ*SA__](B=E(B<=)B<5,
MB>*^;5)``#'`Z-3B__](B>9,B>_H>>+__X/``701#[=$)`@E`/```#T`0```
M=#9,B>_H.^+__TR)[^B3Y/__2(GOZ#OB__](A<`/A5____](B>_HNN3__TR)
MY^A"X___Z?;^__],B>_HP?[__Y#KQP\?@``````/'X``````4TB)^TB#Q(!(
MB>;HY.+__X7`=1@/MT0D""4`\```/0!```!T#ST`H```=`A(@^R`,<!;PTB)
MW[X"````Z"/C__^%P`^4P$B#[(!;#[;`PY!!5S'`059)B?Y!54%454B)]5-(
M@^P8@#X]#Y3`2`'%2(GOZ"WB__](C70D%$&)QTR)]S'`Z)?[__](A<!(B<-T
M-TB)Q^@+XO__1(GZ2#G0#X*\````#[9%`$B#Q0&(`TB#PP&$P'7N2(/$&#'`
M6UU!7$%=05Y!7\-(BSUQ@R``13'DN!````!(@S\`=!](B?I(BT((08/$`4B#
MP@A(A<!U[T&-1"0"2)A(P>`#BQ7^?B``A=(/A1`!``!(B<?'!>E^(``!````
MZ`C@__](A<!)B<4/A!D!``!)8\1(BS4.@R``3(GO2(T<Q0````!(B=KH/^/_
M_TR)+?2"(`!(BP7M@B``2,=$`P@`````1(ED)!1!#[863(GPA-(/A8@```"+
M7"0412GW08U\!P)(P>,#2`,=N8(@`.B8W___2(7`2(D##X2I````BU0D%$B+
M!9V"(`!(BQ3000^V!H3`B`)T)3P]="%,B??K#F8/'T0``$B#QP$\/70.#[9'
M`4B#P@&$P(@"=>K&`CT/'X``````#[9%`$B#Q0&(0@%(@\(!A,!U[>F__O__
M@/H]#X1O____2(/``0^V"(3)#X1@____@/D]=>SI5O___TB)Q@\?`.A_X?__
M2(7`2(D%$8(@`'0026/$2(T<Q0````#I"____TB#Q!BX_____UM=05Q!74%>
M05_##Q]$``!F#Q]$``!!5T%628G^055!5$&\?5)``%532(/L.(`]?Q4```!(
MQP0D?5)``$C'1"0(<U)``$C'1"00@%)``$C'1"08=E)``$C'1"0@>U)``$C'
M1"0H_U-```^$I0```$R+/3@7``!)B>7K'$R)]DR)YS'`Z'[]__]-BV4(28/%
M"$&`/"0`='TQP$R)Y^AE^O__2(7`2(G%=-*`.`!TS4R)]DB)Q^CAX/__2(7`
M=<I,B??HE-___TR)_TB)P^B)W___2(U<`P%(B>_H?-___TB-/`/H\]W__TF)
MZ$B)PTB)QTR)^4R)\KZD4T``,<#H&-___TB)WDR)YS'`Z/?\___I=/___TB#
MQ#A;74%<05U!7D%?PP\?`$B#[#B_C5)``$B+!>![(`!(B40D*#'`2(L%.A8`
M`$B)!"1(BP4W%@``2(E$)`A(BP4S%@``2(E$)!!(BP4O%@``2(E$)!@/MP4K
M%@``9HE$)"`QP.@W^?__,<"_EE)``.@K^?__,<"_GE)``.@?^?__,<"_IU)`
M`.@3^?__,<"_KE)``.@'^?__,<"_OE)``.C[^/__,<"_RE)``.CO^/__,<"_
M8%)``.CC^/__,<"_TU)``.C7^/__,<"_W5)``.C+^/__,<"_YU)``.B_^/__
M,<"_]%)``.BS^/__,<"__5)``.BG^/__,<"_"%-``.CK^/__2(7`=`](B<:_
MTU)``#'`Z-?[__\QP+\94T``Z,OX__](A<!T#TB)QK\K4T``,<#HM_O__S'`
MOS930`#HJ_C__TB%P'0V2(G&O\I20``QP.B7^___,<"^8E-``+^N4D``Z(;[
M__](BT0D*$@S!8IZ(`!U44B#Q#C##Q\`,<"_1E-``.AD^/__2(7`=!%(B<:_
M8%)``#'`Z%#[___KMTB-="01OU=30`"Y"@```/SSIG6C2(UT)!N_8%)``#'`
MZ"G[___KD.A6WO__9I!(@^P(Z,O=__^)Q^@$W/__,=)(A<!T`TB+$$B)T$B#
MQ`C##Q^```````\?@`````!54TB)^TB#[`A(A?]T"`^V+T"$[7402(/$"+]K
M4D``6UWISMS__^@9W?__2`'82(U0_T@YTP^#G@```$B+/4X4```/MD#_#[8W
M0#CP=`GK*@^V"CC!=69(@^H!2#G39I!R[D@YVG4I0#HO=*I(@\0(6UWI?=S_
M_P^V`D`XQG3C2(/J`4@YTW+OZ]AF#Q]$``!(@^H!2#G3<PD/M@(Z!V:0=.Y(
M*=HQR4B-0@)(/0`$``!V#DB#Q`A(B<A;7<.)R.NY2(/"`4B)WK^@NF``Z$+=
M__^YH+I@`.O:2(L]L!,``.N`#Q^```````\?@`````!(B5PD\$B);"3X2(/L
M&$B)^^CZ_O__2(G'Z(+?__](B<4QP.CX]O__A<!T"DB%VW0%@#L`=0](BUPD
M"$B+;"002(/$&,.^9%-``$B)[^A"W?__2#G%==](B=](BVPD$$B+7"0(2(/$
M&.GS]___#Q\`4TB#["")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(C50D".B-
MW?__@#W2>"````^$*0$``(M$)!R`#1%X(``#@\`%2&/(2(7)#XA*`0``\D@/
M*L'R#U@%91,``&8/+@5E$P``#X=,`0``2(T\S0````#HWMS__TB+="002(G!
M2(D%\WP@`$R-2?A(BP9(QT$(:5-``$C'01`@54``2,=!&&Q30`!(B0%$BT0D
M',<%NGP@``0```!!@_@!?BE,C4GXOP$```"Z"````&8/'T0``$B+!!:#QP%(
MB40*&$B#P@A!.?A_ZT&-0`2^X%%``$4QP$B82<<$P0````"+5"0<2(L]6GP@
M`(/"`^B&V?__A<")PW1Q2(L]17P@`.ATV___,<"_OE)``.AD]?__2(7`=!E(
MBSTH?"``Z#?9___H@MK__XG82(/$(%O#2(L]%WP@`$B%_W1PZ#7^___KU`\?
M`.C_V?__2(7`2(G'2(D%[GL@`'1TZ*O:___&!<!V(```Z:_^__](BSW4>R``
MZ#/9__^)P^E\____2(G(2(G*2-'H@^(!2`G0\D@/*L#R#UC`Z9[^__^^4+I@
M`+_V4T``,<#HOMO__[_*4D``Z,#T__](A<!(B<=(B06+>R``#X5S____Z4G_
M__]`MP'HA-O__T%7059!54%428G\O\I20`!54TB)\TB![*@$``!(BP6-=B``
M2(F$))@$```QP.AN]/__2(LM!Q$``$R)YTF)Q4B)[NCMVO__2(7`=#E,B>:_
MYU)``#'`Z$7W__](BY0DF`0``$@S%49V(`!,B>`/A30!``!(@<2H!```6UU!
M7$%=05Y!7\-,B>?H9]G__TR+/;00``!(B=]!B<9,B?[H@MC__TB%P$B)PW2B
M08/&`42)="0,3(VT))`````/'T0``(`[`+AK4D``2`]$V$V%[70/2(G>3(GO
MZ!C;__^%P'1^2(G?Z`S9__^)P4B8#[9$`_\Z10!U'8U!_TB82(T4&)`/MD+_
MQ@(`@^D!2(/J`3I%`'3MBT0D#`'(/?\#```/CRC___]-B>!(B>E(B=J^I%-`
M`$R)]S'`Z'C8__](C70D$$R)]^@;V/__A<!U$0^W1"08)0#P```]`(```'0;
M,?],B?[HO-?__TB%P$B)PP^%3/___^G3_O__O@$```!,B??H+MG__X7`==1,
MB?:_YU)``.@)]O__3(GWZ`78__])B<3IM/[__^@HV?__#Q]``$%7059!54%4
M55-(@>QX@0``2(L%Z'0@`$B)A"1H@0``,<!(B7PD$+_*4D``2,=$)&!O4T``
M2,=$)&AW4T``2,=$)'!K4D``2,=$)'C_4T``2,=$)#`K4T``2,=$)#@D4T``
M2,=$)$"!4T``2,=$)$AR4T``2,=$)%")4T``2,=$)%C_4T``2,>$)(````"-
M4T``2,>$)(@```"24T``2,>$))````#_4T``Z$'R__](A<!(B<-T"8`X``^%
MI`(``#'`2(V<)(````#H`?K__TB%P$F)Q`^$:0(``$$/M@0DA,!T.TR)X0^^
MP(7`>"([!<!S(`!]&DACT$B+!4!T(`#W1-!```4``'4)9@\?1```Q@%?#[9!
M`4B#P0&$P'7(2(UL)#!%,>WK$`\?@`````!(@\4(387M=3Q(BWT`@#\`#X0V
M`@``,<#HH_'__TB%P$B)PW3;2(G'Z$/T__^%P'3/2(G?2(/%".B'UO__28G%
M387M=,1,B>_HQ];__TR)YTB)P^B\UO__C80#!`0``$ACV$B)W^@JU?__2(G?
M28G&Z!_5__](BQ7D#0``38GA0;AD4T``2(G'28G'OJ)30``QP$B)T4B)5"08
M3(GJZ#+6__^^[0$``$R)_^C5UO__,<"_=E)``.@%\?__2(7`#X1C`0``2(G'
MZ/C5__](BTPD$$B)QDB+.>A$_/__2(7`2(G##X0_`0``2(G?Z"36__^#^`-!
MB<`/CXH!```QP.C=\/__A<!U%C'V2(G?Z-/4__^%P(E$)"0/A>,!``"^8E-`
M`+]@4D``,<#HDO/__^@QU___2(M,)!A!B<!!N?]30`!,B?J^R5-``$R)]S'`
M,=OH?]7__^LXZ,C6__^#.!&0=3_H_=;__TB+3"08@\,!08G`08G93(GZOM=3
M0`!,B?<QP$C'!"3_4T``Z$75__^^[0$``$R)]^CHU?__@\`!=+9,B?_H&]?_
M_[_*4D``3(GV,<#H"//__TR)]^@0]?__2(N4)&B!``!(,Q4!<B``3(GP#X4;
M!@``2('$>($``%M=05Q!74%>05_#9@\?1```,<#HR>___TB%P'0+2(G'Z,#4
M__])B<1(@\,(387D#X67_?__2(L[@#\`==1!O)M30`#IR/W__TB+1"002(L8
MZ;3^__](B<?HE/3__TB)W^B`U/__28G&Z73___](C6PD8.L-2(/%"$V%[0^%
MY?W__TB+70"`.P`/A-C]__](B=_H^_'__X7`=-I(B=_H0]3__TF)Q>O-2)B_
MJU-``$B-=`/\N`4```#\2(G!\Z8/A5G^__]!@_@$=!A!C4#\2(M4)!A(F`^V
M1`/_.@(/A3O^__](BTPD$$B+:0A(A>T/A"G^__](B>_H.=3__TB#^`,/AA?^
M__](C70%_+^P4T``N04```#\\Z9(#T3=Z?S]__^Z`@```$C'QN[___^)Q^CQ
MT___BWPD)$B-M"2@````N@8```#H"]3__X"\)*``````=0Z`O"2A````0P^$
M/`0``(M\)"1,C:PDH(```#'V,=))C6TXZ*K3__^_B:O-[[[^W+J8N?#ATL-(
MQX0DH(````$C16=(B;PDJ(```$B)M"2P@```2,>$)+B```!V5#(02(F,),"`
M``!(QX0DR(````````!(QX0DT(````````#'A"08@0````````\?0`"+?"0D
M2(VT)*````"Z`(```.A>T___A<!!B<0/CB4!``!(BXPDR(```$ECU$B+A"30
M@```2(V<)*````"---%(.<Y(B;0DR(```$B#T`!(P>H=2(F$)-"```!(`90D
MT(```(N4)!B!``"%TG12ZW&02(L#3(GO08/L0$F)13A(BT,(2(E%"$B+0Q!(
MB4402(M#&$B)11A(BT,@2(E%($B+0RA(B44H2(M#,$B)13!(BT,X2(/#0$B)
M13CH(=;__T&#_#]_JTECU$B)WDB)[^BQT___1(FD)!B!``#I(/___[A`````
M2&/Z2(VT)*`````IT$B-?#T`03G$B<-!#T[<2&/#2(G"2(E$)"CH=-/__XG8
M`X0D&($``(/X0(F$)!B!```/A=?^__]!*=Q(C9PDH````$@#7"0H3(GOZ)_5
M___I>?___XM\)"3HU='__TB+G"3(@```2(NL)-"```!(B=A(P>@#@^`_2&/0
M@\`!@_@X0<9$%3B`#XXA`@``2&/XND`````Q]BG"2HU\+SA(8]+H'=/__TR)
M[^A!U?__28U].+D'````,<#\\TBK2(GH3(GO0(BL)!.!``!(P>@8B)PD%X$`
M`$R-K"0@@0``B(0D$($``$B)Z$R-I"10@0``2,'H$(B$)!&!``!(B>A,B>U(
MP>@(B(0D$H$``$B)V$C!Z!B(A"04@0``2(G82,'H$(B$)!6!``!(B=@QVTC!
MZ`B(A"06@0``Z++4__](BY0DH(```$B)T(B4)%.!``!(P>@8B(0D4($``$B)
MT$C!Z!"(A"11@0``2(G02(N4)*B```!(P>@(B(0D4H$``$B)T(B4)%>!``!(
MP>@8B(0D5($``$B)T$C!Z!"(A"15@0``2(G02(N4)+"```!(P>@(B(0D5H$`
M`$B)T(B4)%N!``!(P>@8B(0D6($``$B)T$C!Z!"(A"19@0``2(G02(N4)+B`
M``!(P>@(B(0D6H$``$B)T(B4)%^!``!(P>@8B(0D7($``$B)T$C!Z!"(A"1=
M@0``2(G02(N4),"```!(P>@(B(0D7H$``$B)T(B4)&.!``!(P>@8B(0D8($`
M`$B)T$C!Z!"(A"1A@0``2(G02,'H"(B$)&*!```/'T0``$(/MA0C2(GO,<"^
MQ%-``$B#PP%(@\4"Z*C/__](@_L4==[&A"1(@0```$&Y_U-``$V)Z$B+3"08
M3(GZOK530`!,B?<QP.AZS___Z4+Z__^Z.````$AC^#'V*<)*C7PO.$ACTNC\
MT/__Z?']__^`O"2B````00^%MOO__X"\)*,```!##X6H^___@+PDI````$@/
MA9K[__^`O"2E````10^%C/O__XM\)"2Z`@```$C'QL;____H.L___XM\)"1(
MC;0DH````+HI````Z%3/__],C80DH````$&Y_U-``.E0____Z/S/__\/'X0`
M`````$B)7"3H2(EL)/!,B60D^$B![#@(``!(C9PD$`0``$B+!:MK(`!(B80D
M&`@``#'`Z##0__^YZ%-``(G"ONU30``QP$B)W^B*SO__A<!Y-C'M2(N4)!@(
M``!(,Q5Q:R``2(GH=6!(BYPD(`@``$B+K"0H"```3(ND)#`(``!(@<0X"```
MPTB)W[H`!```2(GFZ$#-__^%P(G#>+2->`%(8__H[\S__TB%P'2D2&/;2(G%
M2(GF2(G:2(G'Z(;/___&!"L`ZXSH*\___P\?@`````#I*____P\?1```9@\?
M1```050QP+^N4D``Q@6X:B```553Z,GH__](A<!T"8`X,0^$F0$``#'`Z-3N
M__^Z"P```+X!````O_E30`#H],S__TB%P`^$@````#'M@SUN;R```4B+0!!,
MBV`H?ER["````.LJ2(MW$$B+!5IO(`!(BSP8Z+W/__^%P'4]@\4!2(/#"(U%
M`3D%-6\@`'XK,=*)[DR)Y^@[SO__2(7`=!I(BSCV1PT$=;PQ]KH"````Z*'/
M__](B<;KKXL5`F\@`(U"_SGH#X3/````N@0```"^`0```+_^4T``Z%?,__](
MA<!(B<-T(DB+0!"^`%1``$B+..A.S/__2(M#$$B+./9'#D`/A<X```"Z!```
M`+X!````OP930`#H&<S__TB%P$B)Q70G,<"_YU)``.BQY___2(7`2(G"#X2J
M````2(M%$$B)UDB+..CZR___,<"_RE)``,8%<&D@``!(QP5-:2```````.AX
MY___2(7`2(D%1FX@``^$T````+[M`0``2(G'Z!_-__^%P'0*@_@1=`6#^/]U
M>UM=05S#@^H!#XXH____NP$```!,B>>#PP'H<\O__SD="6X@`'_MZ0O___^`
M>`$`#X1D_O__#Q^$``````#I4/[__^A*S?__9@\?1```Z2+____H!O[__TB%
MP$B)PW0[2(M%$$B)WDB+..A#R___2(G?Z-O-___I//___XG!2(L%L6T@`$B+
M%9IM(`"_L%1``$B+,#'`Z*?-__](BU402(L%D&T@`$B+.DB+,.@!R___Z0+_
M__](BSUY;2``Z)SS__](B05=;2``2(M%$$B+'6)M(`!(BSCV1PT$=#I(BW\0
M2(G>Z/G*__^)PTB+11!(BSCV1PT$=#!(BT<02(G"2(L%,&T@`(G9OX!40`!(
MBS`QP.@KS?__N@(````Q]NB?S?__2(G'Z[FZ`@```#'VZ([-___KQ@\?A```
M````N@540`"^-!U``+\/5$``Z1#-__]F#Q]$``!F#Q]$``!(@^P(Z-?___^Y
M_U-``$4QP+[P3D``2(G*ORM40`!(@\0(Z4W+__^0D)"0D)"0D)!52(GE4TB#
M[`A(BP4H8R``2(/X_W05,=O_T$B+@T"U8`!(@^L(2(/X_W7M2(/$"%O)PY"0
M2(/L".BSS?__2(/$",,``````````````````%!!4E]#3$5!3@`N+@`E<R\E
M<P!,24)0051(`$193$1?3$E"4D%265]0051(`%!%4DPU3$E"`%!%4DQ,24(`
M4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?5$5-4`!005)?1$5"54<`4$%27T-!0TA%`%!!4E]04D]'3D%-10!005)?
M05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`#$`<&%R+0`M90`M+0!#.EQ414U0`"]V87(O=&UP
M+P!414U01$E2`%1-4`!54T52`%5315).04U%`%-94U1%30`E<R5S)7,E<P!P
M87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)3`R>``E<R5S=&5M<"TE=25S`"5S
M)7-T96UP+25U+25U)7,`9FEL90`O<')O8R\E:2\E<P!!4D=6`!@`<&5R;`!P
M97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`#H`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("```````````']30```````0%1````````E<SH@97AE8W5T:6]N
M(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`M(&%B;W)T:6YG('=I=&@@)6DN"@``````````````````````P$-P87(N
M<&P`````````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M
M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O
M;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E
M8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I
M<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S
M92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H
M870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W
M96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@
M(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M
M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI
M8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI
M;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@
M<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O
M8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@
M8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K
M92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G
M=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M
M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@
M("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S
M;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M
M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP
M+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@
M+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@
M("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@
M("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@
M>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H
M*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?
M05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?
M(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[
M4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@
M("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]
M"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O
M9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@
M('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H
M96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@
M<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@
M)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F
M+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@
M("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@
M:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M"B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@
M("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H
M;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?
M=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM0
M05)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@
M("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R
M8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L
M"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U
M8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@
M("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@
M(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K
M97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE
M=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@
M("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@
M("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F
M:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@
M7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@
M("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT[
M"B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@
M)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*
M"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@
M:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N
M;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H
M:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@
M=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D
M;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER
M92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S
M=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@
M=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN
M9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S
M=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET
M:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I
M<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@
M:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@
M("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@
M*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M
M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@
M(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS
M=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB
M=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N
M9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,[
M"B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@
M("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H
M($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@
M)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2![
M"B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@
M)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@
M)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@
M("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N
M86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!
M4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@
M<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@
M("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A
M9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E
M("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF
M="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R
M*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A
M;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D
M(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@
M("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*
M"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO
M8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@
M(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@
M("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*
M"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@
M8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_
M(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@
M;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@
M("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV
M*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@
M("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@
M("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@
M("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I
M;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C
M(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2![
M"B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*
M("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]
M('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I
M"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@
M("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E
M>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@
M1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R
M97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@
M82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES
M<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE
M('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@
M("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,[
M"B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK
M*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU
M97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N
M86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@
M/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M
M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@
M("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@
M("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*
M("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@
M("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@
M("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC
M:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E
M=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H
M(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@
M("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E
M;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I
M=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D
M8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2![
M"B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12([
M"B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@
M)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@
M(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]
M?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![
M>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@
M(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL
M92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I
M<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z
M.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@
M("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@
M("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@
M+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@
M("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O
M(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U
M8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@
M"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R
M97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R
M97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U
M:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@
M1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!A='1R:6)U
M=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A
M<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L
M:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS
M=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@
M('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@
M("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*
M("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@
M("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@
M("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[
M"B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L
M(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@
M("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*
M("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H
M)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@
M("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@
M:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE
M;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L
M("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E
M;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C
M;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE
M"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M
M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@
M("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@
M("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D[
M"B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@
M(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@
M("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![
M"B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@
M("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@
M)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F
M:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<
M;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO
M;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE
M("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*
M?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3(*"E]?
M14Y$7U\*`````1L#.]`````9````5&[__^P```!D;___%`$``*1O__\L`0``
ME(7__UP!``!TAO__A`$``,2&__^D`0``Y(;__[P!```TA___U`$``%2'___L
M`0``)(C__P0"``!TB?__)`(``,2)__]$`@``U(O__WP"``#DC/__M`(``*2.
M___,`@``U([__^0"``#$C___!`,``#20__\<`P``))+__SP#``#4D___=`,`
M``2=__^L`P``U)W__\P#``#DG?__Y`,``+2@__\$!```U*#__QP$```4````
M``````%Z4@`!>!`!`PP'")`!```D````'````&`?0`"<`````$$.$(8"0PT&
M0HT#2X,%C`0`````````%````$0```!P($``-```````````````+````%P`
M``"P($``\!4```!"#A!&#AA"#B!!#BB&!8P$C0..`D0.,$<.N`2#!@``)```
M`(P```"@-D``V0````!*CP*,!5X.0(X#C02&!H,'`````````!P```"T````
M@#=``$\`````00X000X8@P.&`D<.,```%````-0```#0-T``%0````!$#B``
M````%````.P```#P-T``30````!$#A``````%`````0!``!`.$``'@````!$
M#A``````%````!P!``!@.$``P@````!(#A"#`@``'````#0!```P.4``0@$`
M``!*@P:,!%D.L`&.`HT#A@4<````5`$``(`Z0`!/`````$$.$(,"1PZ0`0``
M`````#0```!T`0``T#I```4"````0@X01`X8C@./`D4.($(.*$$.,(8&C`6-
M!$0..$0.4(,'````````-````*P!``#@/$``#0$```!"#A!"#AB.`X\"10X@
M0@XHC`6-!$<.,$$..$0.<(,'A@8````````4````Y`$``/`]0`"^`0```$0.
M0``````4````_`$``+`_0``B`````$0.$``````<````%`(``.`_0`#B````
M`$$.$$$.&(,#A@)'#B```!0````T`@``T$!``&T`````3@X@A@*#`QP```!,
M`@``0$%``/`!````00X01`XP@P(`````````-````&P"```P0T``K`$```!"
M#A!"#AA"#B!"#BB,!8T$C@./`DD.,$$..(,'A@9*#N`)```````T````I`(`
M`.!$0``H"0```$(.$$(.&$(.($(.*$$.,$$..$<.L(,"@P>&!HP%C02.`X\"
M`````!P```#<`@``$$Y``,D`````5@[`$(P"A@.#!```````%````/P"``#@
M3D``!0``````````````'````!0#``#P3D``R`(```!"#A!/#AA!#B"#!(8#
MC`(4````-`,``,!10``4```````````````4````3`,``.!10``G`````$0.
M$````````````````/__________``````````#__________P``````````
M```````````!``````````$``````````0````````#^`0````````$`````
M````"`(````````!`````````!8"`````````0`````````C`@````````\`
M````````<P,````````,`````````(`;0```````#0````````!$4D``````
M``0`````````,`)````````%`````````.@.0```````!@````````!8!4``
M``````H`````````MP0````````+`````````!@`````````%0``````````
M``````````,`````````4+=@```````"`````````(@%````````%```````
M```'`````````!<`````````^!5````````'`````````)`40```````"```
M``````!H`0````````D`````````&`````````#^__]O`````'`40```````
M____;P`````!`````````/#__V\`````H!-`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!PM6``````
M``````````````````````"J&T```````+H;0```````RAM```````#:&T``
M`````.H;0```````^AM````````*'$```````!H<0```````*AQ````````Z
M'$```````$H<0```````6AQ```````!J'$```````'H<0```````BAQ`````
M``":'$```````*H<0```````NAQ```````#*'$```````-H<0```````ZAQ`
M``````#Z'$````````H=0```````&AU````````J'4```````#H=0```````
M2AU```````!:'4```````&H=0```````>AU```````"*'4```````)H=0```
M````JAU```````"Z'4```````,H=0```````VAU```````#J'4```````/H=
M0```````"AY````````:'D```````"H>0```````.AY```````!*'D``````
M`%H>0```````:AY```````!Z'D```````(H>0```````FAY```````"J'D``
M`````+H>0```````RAY```````#:'D```````.H>0```````^AY````````*
M'T```````!H?0```````*A]````````Z'T```````$H?0```````_U-`````
M`````````````&"U8```````_____P`````054```````.E;`````````"1&
M<F5E0E-$.B!S<F,O;&EB+V-S=2]A;60V-"]C<G0Q+F,L=B`Q+C$W+C(N,2XR
M+C$@,C`Q,2\Q,2\Q,2`P-#HR,#HR,B!K96YS;6ET:"!%>'`@)``D1G)E94)3
M1#H@<W)C+VQI8B]C<W4O8V]M;6]N+V-R=&)R86YD+F,L=B`Q+C<N,BXQ+C(N
M,2`R,#$Q+S$Q+S$Q(#`T.C(P.C(R(&ME;G-M:71H($5X<"`D`$=#0SH@*$=.
M52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``"1&<F5E0E-$
M.B!S<F,O;&EB+V-S=2]A;60V-"]C<G1I+E,L=B`Q+CDN,BXQ+C(N,2`R,#$Q
M+S$Q+S$Q(#`T.C(P.C(R(&ME;G-M:71H($5X<"`D``!'0T,Z("A'3E4I(#0N
M,BXQ(#(P,#<P.#,Q('!A=&-H960@6T9R965"4T1=``!'0T,Z("A'3E4I(#0N
M,BXQ(#(P,#<P.#,Q('!A=&-H960@6T9R965"4T1=``!'0T,Z("A'3E4I(#0N
M,BXQ(#(P,#<P.#,Q('!A=&-H960@6T9R965"4T1=``!'0T,Z("A'3E4I(#0N
M,BXQ(#(P,#<P.#,Q('!A=&-H960@6T9R965"4T1=```D1G)E94)31#H@<W)C
M+VQI8B]C<W4O86UD-C0O8W)T;BY3+'8@,2XX+C(N,2XR+C$@,C`Q,2\Q,2\Q
M,2`P-#HR,#HR,B!K96YS;6ET:"!%>'`@)```+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O="YP;'0`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M``````````)``````````@```````!4````````````````````!````````
M````````````$P````<````"`````````!@"0```````&`(````````8````
M````````````````!````````````````````"$````%`````@`````````P
M`D```````#`"````````)`,````````$``````````@`````````!```````
M```G````"P````(`````````6`5```````!8!0```````)`)````````!0``
M``$````(`````````!@`````````+P````,````"`````````.@.0```````
MZ`X```````"W!````````````````````0```````````````````#<```#_
M__]O`@````````"@$T```````*`3````````S``````````$``````````(`
M`````````@````````!$````_O__;P(`````````<!1```````!P%```````
M`"``````````!0````$````(````````````````````4P````0````"````
M`````)`40```````D!0```````!H`0````````0`````````"``````````8
M`````````%T````$`````@````````#X%4```````/@5````````B`4`````
M```$````"P````@`````````&`````````!G`````0````8`````````@!M`
M``````"`&P```````!,````````````````````$````````````````````
M8@````$````&`````````)0;0```````E!L```````#``P``````````````
M````!``````````0`````````&T````!````!@````````!@'T```````&`?
M````````Y#(``````````````````!````````````````````!S`````0``
M``8`````````1%)```````!$4@````````X````````````````````$````
M````````````````>0````$````"`````````&!20```````8%(```````"J
M7@``````````````````(````````````````````($````!`````@``````
M```,L4````````RQ````````U`````````````````````0`````````````
M``````"/`````0````(`````````X+%```````#@L0```````&0#````````
M```````````(````````````````````F0````$````#`````````$BU8```
M````2+4````````0````````````````````"````````````````````*``
M```!`````P````````!8M6```````%BU````````$```````````````````
M``@```````````````````"G`````0````,`````````:+5@``````!HM0``
M``````@````````````````````(````````````````````K`````8````#
M`````````'"U8```````<+4```````#@`0````````4`````````"```````
M```0`````````+4````!`````P````````!0MV```````%"W````````\`$`
M``````````````````@`````````"`````````"^`````0````,`````````
M0+E@``````!`N0```````#`````````````````````(````````````````
M````Q`````@````#`````````("Y8```````<+D```````!(!0``````````
M````````(````````````````````,D````!````````````````````````
M`'"Y````````.0(```````````````````$````````````````````!````
M`P````````````````````````"INP```````-(````````````````````!
/````````````````````
